@@ -1,5 +1,7 @@
 mod execute;
+mod query;
 mod sync;
 
 pub use execute::on_execute;
+pub use query::on_query;
 pub use sync::on_sync;
